@@ -1,6 +1,6 @@
 /*
      This file is part of libextractor.
-     (C) 2002, 2003, 2004, 2005 Vidyut Samanta and Christian Grothoff
+     (C) 2002, 2003, 2004, 2005, 2006 Vidyut Samanta and Christian Grothoff
 
      libextractor is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -23,13 +23,16 @@
 
 #ifdef __cplusplus
 extern "C" {
+#if 0 /* keep Emacsens' auto-indent happy */
+}
+#endif
 #endif
 
 /**
  * 0.2.6-1 => 0x00020601
  * 4.5.2-0 => 0x04050200
  */
-#define EXTRACTOR_VERSION 0x00050900
+#define EXTRACTOR_VERSION 0x00051300
 
 #include <stdio.h>
 
@@ -140,6 +143,31 @@ typedef enum {
   EXTRACTOR_ORIENTATION = 87,
   EXTRACTOR_TEMPLATE = 88,
   EXTRACTOR_SPLIT = 89,
+  EXTRACTOR_PRODUCTVERSION = 90,  
+  EXTRACTOR_LAST_SAVED_BY = 91,
+  EXTRACTOR_LAST_PRINTED = 92,  
+  EXTRACTOR_WORD_COUNT = 93,
+  EXTRACTOR_CHARACTER_COUNT = 94,
+  EXTRACTOR_TOTAL_EDITING_TIME = 95,
+  EXTRACTOR_THUMBNAILS = 96,
+  EXTRACTOR_SECURITY = 97,
+  EXTRACTOR_CREATED_BY_SOFTWARE = 98,
+  EXTRACTOR_MODIFIED_BY_SOFTWARE = 99,
+  EXTRACTOR_REVISION_HISTORY = 100,
+  EXTRACTOR_LOWERCASE = 101,
+  EXTRACTOR_COMPANY = 102,
+  EXTRACTOR_GENERATOR = 103,
+  EXTRACTOR_CHARACTER_SET = 104,
+  EXTRACTOR_LINE_COUNT = 105,
+  EXTRACTOR_PARAGRAPH_COUNT = 106,
+  EXTRACTOR_EDITING_CYCLES = 107,
+  EXTRACTOR_SCALE = 108,
+  EXTRACTOR_MANAGER = 109,
+  EXTRACTOR_MOVIE_DIRECTOR = 110,
+  EXTRACTOR_DURATION = 111,
+  EXTRACTOR_INFORMATION = 112,
+  EXTRACTOR_FULL_NAME = 113,
+  EXTRACTOR_CHAPTER = 114,
 } EXTRACTOR_KeywordType;
 
 /**
@@ -400,6 +428,9 @@ char * EXTRACTOR_binaryEncode(const unsigned char * data,
 			      size_t size);
 
 
+#if 0 /* keep Emacsens' auto-indent happy */
+{
+#endif
 #ifdef __cplusplus
 }
 #endif
