@@ -77,7 +77,7 @@ static struct {
    { "Comment", EXTRACTOR_COMMENT},
    { "Copyright", EXTRACTOR_COPYRIGHT},
    { "Source", EXTRACTOR_SOURCE},
-   { "Creation Time", EXTRACTOR_DATE},
+   { "Creation Time", EXTRACTOR_CREATION_DATE},
    { "Title", EXTRACTOR_TITLE},
    { "Software", EXTRACTOR_SOFTWARE},
    { "Disclaimer", EXTRACTOR_DISCLAIMER},
@@ -282,7 +282,7 @@ static struct EXTRACTOR_Keywords * processzTXt(const char * data,
 
 
 
-struct EXTRACTOR_Keywords * libextractor_png_extract(char * filename,
+struct EXTRACTOR_Keywords * libextractor_png_extract(const char * filename,
                                                      const char * data,
                                                      size_t size,
                                                      struct EXTRACTOR_Keywords * prev) {
